<?php
/*
Plugin Name: Tippy
Plugin URI: http://www.musterion.net/tippy/
Description: Simple plugin to display tooltips within your WordPress blog.
Version: 2.0.2
Author: Chris Roberts
Author URI: http://www.musterion.net/
*/

/*  Copyright 2007 Chris Roberts (email : chris@musterion.net)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$Tippy_Version = "2.0.2";
$Tippy_Loaded = 0;

// Add to the Admin function list
if (! function_exists('tippy_addoptions')) {
  function tippy_addoptions() {
    if (function_exists('add_options_page')) {
      add_options_page('Tippy Plugin Options', 'Tippy', 9, basename(__FILE__), 'tippy_options_subpanel');
    }
  }
}

if (! function_exists('tippy_options_subpanel')) {
  function tippy_options_subpanel() {
    global $wpdb, $table_prefix, $Tippy_Version;

    $oldvers = get_option('tippy_version');

    // This is the first release of tippy, no upgrade stuff necessary. Putting
    // framework code here for future expansion.

    if ($oldvers < $Tippy_Version)
    {
		update_option('tippy_version', $Tippy_Version);
    }

    // Check for default values
	$defaultsLoaded = 0;
	if (get_option('tippy_version') == "")
	{
		update_option('tippy_version', $Tippy_Version);
		$defaultsLoaded = 1;
	}
	
	if (get_option('tippy_tipPosition') == "")
	{
		update_option('tippy_tipPosition', 'follow');
		$defaultsLoaded = 1;
	}
	
	if (get_option('tippy_Moveable') == "")
	{
		update_option('tippy_Moveable', 'true');
		$defaultsLoaded = 1;
	}
	
	if (get_option('tippy_Resizable') == "")
	{
		update_option('tippy_Resizable', 'true');
		$defaultsLoaded = 1;
	}
	
	if (get_option('tippy_multipleTips') == "")
	{
		update_option('tippy_multipleTips', 'true');
		$defaultsLoaded = 1;
	}
	
	if (get_option('tippy_openTip') == "")
	{
		update_option('tippy_openTip', 'hover');
		$defaultsLoaded = 1;
	}
	
	// Is this a new install? Load default data
    if ($defaultsLoaded > 0)
    {
    	?>
	  		<div class="updated"><p><strong>Default tooltip settings loaded.</strong></p></div>
	  	<?php
    }

    if (isset($_POST['info_update'])) {
		if ($_POST['tippy_Moveable'] == "") {
			$_POST['tippy_Moveable'] = "false";
		}
		
		if ($_POST['tippy_Resizable'] == "") {
			$_POST['tippy_Resizable'] = "false";
		}
		
		if ($_POST['tippy_multipleTips'] == "") {
			$_POST['tippy_multipleTips'] = "false";
		}
		
		update_option('tippy_tipPosition', $_POST['tippy_tipPosition']);
		update_option('tippy_Moveable', $_POST['tippy_Moveable']);
		update_option('tippy_Resizable', $_POST['tippy_Resizable']);
		update_option('tippy_multipleTips', $_POST['tippy_multipleTips']);
		update_option('tippy_openTip', $_POST['tippy_openTip']);

		?>
			<div class="updated">
            <p><strong>Your options have been updated.</strong></p>
            </div>
		<?php
    }
?>

<style type="text/css">
div.tippyOptionSection {
 margin-bottom: 20px;
 margin-left: 10px;
}

span.tippyOptionLabel {
 font-size: 16px;
}

div.tippyOptions {
 margin-left: 15px;
}

div.tippyOptionLeft {
 width: 125px;
 float: left;
}

div.tippyOptionRight {
 float: left;
}

div.clearOptions {
 margin-bottom: 5px;
 clear: both;
}
</style>

<div class="wrap">
	<h2>Tippy Options</h2>
	<form method="post">

	<span class="tippyOptionLabel">How to use</span><br />
	<div class="tippyOptionSection">
		Example:<br />
        [tippy title="example tooltip" reference="http://www.musterion.net/"]This is my nifty tooltip![/tippy]<br />
		Be sure and include the title attribute or nothing will happen. You can include html between the tippy tags. The reference tag is optional. If set, the tooltip header will link to the reference.<br />
		<br />
		Tooltip look can be set up via CSS. Look in your tippy plugin directory at the file dom_tooltip.css and make changes there.
	</div>

    <span class="tippyOptionLabel">Tooltip Display Options</span><br />
	<div class="tippyOptionSection">
	    Here you can set default options for the tooltip. Note that some of these options won't work right together and are auto-adjusted by the plugin.<br /><br />

		<div class="tippyOptions">
        	How should the tooltip be activated? By hovering over the link or by clicking the link?<br />
			<input id="tippy_openTip_hover" name="tippy_openTip"  type="radio" value="hover" <?php if(get_option('tippy_openTip') == "hover") echo "checked" ?> />
				<label for="tippy_openTip_hover" title="Tooltip opens when user hovers over the link">
					Tooltip opens on hover
				</label><br />

			<input id="tippy_openTip_click" name="tippy_openTip" type="radio" value="click" <?php if(get_option('tippy_openTip') == "click") echo "checked" ?> />
				<label for="tippy_openTip_click" title="Tooltip opens when user clicks the link">
					Tooltip opens on click
				</label><br /><br />

            When the tooltip is open, should it follow the mouse while over the link, remain frozen in place while over the link, or remain frozen in place until the user closes it?<br />
			<input id="tippy_tipPosition_follow" name="tippy_tipPosition"  type="radio" value="follow" <?php if(get_option('tippy_tipPosition') == "follow") echo "checked" ?> />
				<label for="tippy_tipPosition_follow" title="Tooltip follows the mouse over the tippy link">
					Tooltip follows mouse
				</label><br />

			<input id="tippy_tipPosition_sticky" name="tippy_tipPosition" type="radio" value="sticky" <?php if(get_option('tippy_tipPosition') == "sticky") echo "checked" ?> />
				<label for="tippy_tipPosition_sticky" title="The tooltip doesn't move around">
					Tooltip frozen in place while the tooltip is open
				</label><br />
                
            <input id="tippy_tipPosition_fixed" name="tippy_tipPosition" type="radio" value="frozen" <?php if(get_option('tippy_tipPosition') == "frozen") echo "checked" ?> />
				<label for="tippy_tipPosition_fixed" title="The tooltip doesn't move around">
					Tooltip frozen in place until user closes it
				</label><br /><br />
                
            Will the user be able to move tooltips around? (Only works if the tooltip is set to remain open)<br />
            <input id="tippy_Moveable" name="tippy_Moveable" type="checkbox" value="true" <?php if(get_option('tippy_Moveable') == "true") echo "checked" ?> />
				<label for="tippy_Moveable" title="Allow the user to move the tooltip around">
					Allow moveable tooltips
				</label><br />
                (Note: This is automatically enabled if multiple tips are allowed.)<br /><br />
                
            Will the user be able to resize the tooltip? (Only works if the tooltip is set to remain open)<br />
            <input id="tippy_Resizable" name="tippy_Resizable" type="checkbox" value="true" <?php if(get_option('tippy_Resizable') == "true") echo "checked" ?> />
				<label for="tippy_Resizable" title="Allow the user to resize the tooltip">
					Allow resizable tooltips
				</label><br /><br />
                
            Can multiple tooltips be open? (Only works if the tooltip is set to remain open; if this is set then it automatically allows tooltips to be moved)<br />
            <input id="tippy_multipleTips" name="tippy_multipleTips" type="checkbox" value="true" <?php if(get_option('tippy_multipleTips') == "true") echo "checked" ?> />
				<label for="tippy_multipleTips" title="Allow the user to have multiple tooltips open">
					Allow multiple tooltips
				</label><br /><br />
		</div>
	</div>

    <input type="submit" name="info_update" value="Update Options" /><br /><br />

	</form>
</div>

<?php
  }
}

if (! function_exists('tippy_getspot')) {
	function tippy_getspot($content) {

		preg_match_all('/\[tippy([^\]]+)?\]([^\[]+)\[\/tippy\]/', $content, $tippyMatches);
		for ($i = 0 ; $i < sizeof($tippyMatches[0]) ; $i++)
		{
			$options = $tippyMatches[1][$i];
			$tippyText = $tippyMatches[2][$i];

			$tippyTitle = "";
			$tippyHref = "";

			preg_match('/title=["\']([^"]+)["\']/', $options, $titles);
			if (is_array($titles))
			{
				$tippyTitle = $titles[1];
			}

			preg_match('/reference=["\']([^"]+)["\']/', $options, $hrefs);
			if (is_array($hrefs))
			{
				$tippyHref = $hrefs[1];
			}
			
			$tippyTitle = str_replace("\\", "\\\\", $tippyTitle);
			$tippyNewTitle = str_replace("'", "&#8217;", $tippyTitle);

			$tippyNewText = str_replace("\n", "", $tippyText);
			$tippyNewText = str_replace("\r", "", $tippyNewText);
			$tippyNewText = str_replace("'", "&#8217;", $tippyNewText);
			$tippyNewText = str_replace("\\", "&#92;", $tippyNewText);
			$tippyNewText = str_replace("(", "&#40;", $tippyNewText);
			$tippyNewText = str_replace(")", "&#41;", $tippyNewText);

			if ($tippyHref != "")
			{
				$addHref = $tippyHref;
			} else {
				$addHref = "";
			}
			
			if (get_option('tippy_openTip') == "hover")
			{
				$activateTippy = "onMouseOver";
				
				if ($tippyHref != "")
				{
					$addHref = 'href="'. $tippyHref .'" ';
				}
			} else {
				$activateTippy = "onMouseUp";
				$addHref = "";
			}
				
			$tippyString = '<a '. $addHref .'class="tippy_link" '. $activateTippy .'="domTip_toolText(\'tip'. $i .'\', \''. htmlentities($tippyNewText) .'\', \''. trim($tippyNewTitle) .'\', \''. $tippyHref .'\');" onMouseOut="domTip_clearTip(\'false\')">'. $tippyTitle .'</a>';

			$content = str_replace($tippyMatches[0][$i], $tippyString, $content);
		}

		return $content;
	}
}

if (! function_exists('tippy_display')) {
	$tippy_setdisplay = 0;

	function tippy_display($content = '') {
		global $tippy_setdisplay, $wpdb;

		$wpurl = get_bloginfo('wpurl');

		if ($tippy_setdisplay == 0) {
			$tippy_setdisplay = 1;

			$content .= '<link rel="stylesheet" type="text/css" href="'. $wpurl .'/wp-content/plugins/tippy/dom_tooltip.css" media="screen" />';
			$content .='<script type="text/javascript" src="'. $wpurl .'/wp-content/plugins/tippy/dom_tooltip.js"></script>';
			$content .= '<script type="text/javascript">'.
			'domTip_setSettings(\''. get_option('tippy_multipleTips') .'\', \''. get_option('tippy_Moveable') .'\', \''. get_option('tippy_Resizable') .'\', \''. get_option('tippy_tipPosition') .'\');'.
			'</script>';
		}

		echo $content;

	}
}

add_filter('the_content', 'tippy_getspot', 4);
add_action('wp_head', 'tippy_display', 40);
add_action('admin_menu', 'tippy_addoptions');

add_filter('comment_text', 'tippy_getspot', 4);
add_filter('comment_text', 'tippy_display', 40);

?>